==============
Biblion README
==============



.. image:: https://img.shields.io/travis/eldarion/biblion.svg
    :target: https://travis-ci.org/eldarion/biblion

.. image:: https://img.shields.io/coveralls/eldarion/biblion.svg
    :target: https://coveralls.io/r/eldarion/biblion

.. image:: https://img.shields.io/pypi/dm/biblion.svg
    :target:  https://pypi.python.org/pypi/biblion/

.. image:: https://img.shields.io/pypi/v/biblion.svg
    :target:  https://pypi.python.org/pypi/biblion/

.. image:: https://img.shields.io/badge/license-BSD-blue.svg
    :target:  https://pypi.python.org/pypi/biblion/



Biblion was the eldarion.com blog which we've extracted and open sourced. It
is currently positioned as being used for site/project blogs such as
eldarion.com and eldarionproject.com. We intend for this app to replace the
internal eldarion blog app once we've made it feature complete.


Current features include:

 * support for multiple channels (e.g. technical vs business)
 * use of Creole as markup format
 * Atom and RSS feeds
 * previewing of blog posts before publishing
 * optional ability to announce new posts on twitter
